# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# The name of the panel group to be added to HORIZON_CONFIG. Required.
PANEL_GROUP = 'admin_vitrage_panel_group'
# The display name of the PANEL_GROUP. Required.
PANEL_GROUP_NAME = 'Vitrage'
# The name of the dashboard the PANEL_GROUP associated with. Required.
PANEL_GROUP_DASHBOARD = 'admin'

ADD_XSTATIC_MODULES = [
    ('xstatic.pkg.lodash', ['lodash.js']),
    ('xstatic.pkg.graphlib', ['graphlib.core.js']),
    ('xstatic.pkg.dagre', ['dagre.core.js']),
    ('xstatic.pkg.dagre_d3', ['dagre-d3.core.js']),
]
